summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/starpixmap.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:39:55 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:39:55 +0000
commit0a6e0958c03e41c87b15557b6f407874f20c2f8d (patch)
tree2cdd58c4013b1be09cfcbb4ddae2b05712b9aeee /kstars/kstars/starpixmap.h
parent83f9dfafc157ff7823804b3ff457b43d021a5b4b (diff)
downloadtdeedu-0a6e0958c03e41c87b15557b6f407874f20c2f8d.tar.gz
tdeedu-0a6e0958c03e41c87b15557b6f407874f20c2f8d.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1157642 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kstars/kstars/starpixmap.h')
-rw-r--r--kstars/kstars/starpixmap.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kstars/kstars/starpixmap.h b/kstars/kstars/starpixmap.h
index e37bb18e..70b64679 100644
--- a/kstars/kstars/starpixmap.h
+++ b/kstars/kstars/starpixmap.h
@@ -18,13 +18,13 @@
#ifndef STARPIXMAP_H
#define STARPIXMAP_H
-#include <qpixmap.h>
+#include <tqpixmap.h>
/**@class StarPixmap
*Stores a two-dimensional array of star images, indexed by both size and color.
*Based on a star's spectral type, brightness, and the current zoom level, the appropriate
*image is selected from the array in the SkyMap::drawSymbol() function.
*A two-dimensional array of QPixmap star images
*@author Thomas Kabelmann
*@version 1.0
*/
@@ -45,7 +45,7 @@ class StarPixmap {
*@param color the spectral type (one of O,B,A,F,G,K,M,N,P)
*@param s the size index
*/
- QPixmap* getPixmap (QChar *color, int s);
+ TQPixmap* getPixmap (TQChar *color, int s);
/**Change the Color mode. Regenerate the star image array.
*@param newMode the new Color Mode to use.
@@ -65,7 +65,7 @@ class StarPixmap {
private:
- QPixmap starPixmaps[10][26]; // the preloaded starpixmaps 10 colors/ 24 sizes
+ TQPixmap starPixmaps[10][26]; // the preloaded starpixmaps 10 colors/ 24 sizes
int size, colorMode, colorIntensity;
/**Construct the array of star images*/
@@ -18,13 +18,13 @@
*Based on a star's spectral type, brightness, and the current zoom level, the appropriate
*image is selected from the array in the SkyMap::drawSymbol() function.
- *A two-dimensional array of QPixmap star images
+ *A two-dimensional array of TQPixmap star images
*@author Thomas Kabelmann
*@version 1.0